pydevDAG._attributes._diffstatus module — pydevDAG 1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._attributes package »

# pydevDAG._attributes._diffstatus module

## pydevDAG._diffstatus

Diffstatus of graph elements.

class `pydevDAG._attributes._diffstatus.` `DiffStatus`

  Bases: `pydevDAG._attributes._metaclasses.AttributeValue`

  Abstract class that represents a difference status.

class `pydevDAG._attributes._diffstatus.` `DiffStatuses`

  Bases: `pydevDAG._attributes._metaclasses.AttributeValues`

  Enumeration of diff statuses.

  `ADDED` = Added
  `REMOVED` = Removed
  classmethod `values`()

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._attributes package »